# Armilla Client

## To install the Armilla library

`pip install armilla`

## To view existing standard use_cases

see submit_tool.py and use_cases/cases.py

## To submit projects using submit tool

`python submit_tool.py --user <user_name> --pw <password> --env <env LOCAL|DEMO|PRODUCTION|STAGING> --case <specific case or ALL> --run --all_models`
